@@ -2,13 +2,19 @@
 #######################################################################
 """MixIn class for content viewlet
 
-$Id: contenticons.py 51952 2008-10-23 20:14:11Z cray $
+$Id: contenticons.py 52321 2009-01-13 13:43:00Z corbeau $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52321 $"
 
-from ng.skin.base.page.contentlet.viewletbase import ViewletBase
+from ng.lib.viewletbase import ViewletBase
+from ng.content.article.interfaces import IIconContainer
 
 class ContentIcons(ViewletBase) :
     """ Content """
+
+    @property
+    def images(self) :
+        
+        return IIconContainer(self.context).values()
