@@ -2,20 +2,27 @@
 #######################################################################
 """The definitions of a few viewlet provider.
 
-$Id: interfaces.py 51952 2008-10-23 20:14:11Z cray $
+$Id: interfaces.py 52446 2009-02-02 13:41:19Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52446 $"
 
 from zope.viewlet import interfaces
 from viewletmain.interfaces import INewsListBoxProvider, \
     ICurrentBoxProvider
 from viewletsubscribe.interfaces import ISubscribeProvider
+from viewletloginbox.interfaces import ILoginBoxProvider
+from viewletrubriclist.interfaces import IRubricListProvider,IRubricCloudProvider,IRubricAllCloudProvider
 
-class IColumn( INewsListBoxProvider, 
+class IColumn( 
+    INewsListBoxProvider, 
     ICurrentBoxProvider, 
-    ISubscribeProvider, 
+    ISubscribeProvider,
+    ILoginBoxProvider, 
+    IRubricListProvider,
+    IRubricCloudProvider,
+    IRubricAllCloudProvider,
     interfaces.IViewletManager) :
     """ Column viewlet provider """
 
