@@ -3,19 +3,20 @@
 """Mix-in class for the viewlet display content of parent
 container current object.
 
-$Id: currentbox.py 51952 2008-10-23 20:14:11Z cray $
+$Id: currentbox.py 52318 2009-01-13 12:33:50Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52318 $"
 
 from zope.app.container.interfaces import  IContainer        
 from zope.app.zapi import getUtility
 from zope.app.zapi import getSiteManager
 from zope.proxy import sameProxiedObjects
 from ng.content.article.interfaces import IContentContainer
+from ng.lib.viewletbase import ViewletBase
 
-class CurrentBox(object) :
+class CurrentBox(ViewletBase) :
     """ Folder List """
 
     @property
