@@ -2,11 +2,11 @@
 #######################################################################
 """Mix-in class for viewlet with last rss news
 
-$Id: newslistbox.py 51952 2008-10-23 20:14:11Z cray $
+$Id: newslistbox.py 52421 2009-01-31 15:40:52Z cray $
 """
 __author__  = "Andrey Orlov,2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52421 $"
 
 
 from mainbox import MainBox
@@ -16,12 +16,8 @@ class NewsListBox(MainBox) :
     """ Folder List """
 
     foldername = "news"
-    @property
-    def values(self) :
+    registry = "news"
+    
+    def _values(self) :
         return IObjectQueue(self.folder).values()        
 
-class CommonNewsListBox(NewsListBox) :
-    """ Folder List """
-
-    foldername = "Main"
-
